/*
Copyright (c) 2021 Steffen Illhardt

Permission is hereby granted, free of charge, to any person obtaining a copy of
this software and associated documentation files (the "Software"), to deal in
the Software without restriction, including without limitation the rights to
use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies of
the Software, and to permit persons to whom the Software is furnished to do so,
subject to the following conditions:

The above copyright notice and this permission notice shall be included in all
copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS
FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR
COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER
IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN
CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
*/

// MinGW -- add libs to linker options: ole32, uuid

#ifndef DETECTCP_H_INCLUDED__
#  define DETECTCP_H_INCLUDED__
#  ifdef __cplusplus
extern "C"
#  endif // __cplusplus

/** \brief Try to determine the codepage of a string.
 *         NOTE: Do not rely on the returned codepage ID being correct.
 * \param src           String of bytes.
 * \param src_size      Number of bytes in src, without terminating 0 (critical condition) if any.
 * \param preferred_cp  Indicate a codepage ID to be preferred, or pass 0 to use the default.
 * \return  Codepage ID if the function succeeded to guess one,
 *          0 if the function is unable to detect a codepage but the data is likely text,
 *         -1 if the data is more likely binary rather than text. */
unsigned GetInputCodepage(const void *src, int src_size, unsigned preferred_cp);

#endif // ! DETECTCP_H_INCLUDED__
